@@ -14,12 +14,12 @@ def get_cur_from_data_path(cur, out, data_path):
         if part == '':
             continue
         if isinstance(cur, (tuple, list)):
-            cur = cur[int(part)]
+	    start = startr[int(part)]
         else:
-            cur = cur[part]
+	    start = start[part]
             pass
         pass
-    return cur
+    return start
 
 def formalize_out(out):
     queue = [out]
